@@ -27,7 +27,7 @@
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-commands-file.c,v 1.5 2006/02/19 21:46:48 pborelli Exp $
+ * $Id: gedit-commands-file.c,v 1.6.2.2 2006/05/31 07:13:46 pborelli Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -121,7 +121,7 @@ load_file_list (GeditWindow         *window,
 				/* There is only a single file to load */
 				gchar *uri_for_display;
 
-				uri_for_display = gnome_vfs_format_uri_for_display (uri);
+				uri_for_display = gedit_utils_format_uri_for_display (uri);
 
 				gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
 							       window->priv->generic_message_cid,
@@ -526,7 +526,7 @@ replace_read_only_file (GtkWindow   *parent,
 
 	gedit_debug (DEBUG_COMMANDS);
 
-	full_formatted_uri = gnome_vfs_format_uri_for_display (uri);
+	full_formatted_uri = gedit_utils_format_uri_for_display (uri);
 	g_return_val_if_fail (full_formatted_uri != NULL, FALSE);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
@@ -610,13 +610,15 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 		doc = gedit_tab_get_document (tab);
 		g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
 
-		uri_for_display = gnome_vfs_format_uri_for_display (uri);
+		uri_for_display = gedit_utils_format_uri_for_display (uri);
 
 		gedit_statusbar_flash_message (GEDIT_STATUSBAR (window->priv->statusbar),
 					        window->priv->generic_message_cid,
 					       _("Saving file '%s'\342\200\246"),
 					       uri_for_display);
 
+		g_free (uri_for_display);
+
 		_gedit_tab_save_as (tab, uri, encoding);
 	}
 
@@ -669,6 +671,7 @@ confirm_overwrite_callback (GtkFileChooser *dialog,
 			    gpointer        data)
 {
 	gchar *uri;
+	GtkFileChooserConfirmation res;
 
 	gedit_debug (DEBUG_COMMANDS);
 
@@ -677,15 +680,19 @@ confirm_overwrite_callback (GtkFileChooser *dialog,
 	if (is_read_only (uri))
 	{
 		if (replace_read_only_file (GTK_WINDOW (dialog), uri))
-			return GTK_FILE_CHOOSER_CONFIRMATION_ACCEPT_FILENAME;
+			res = GTK_FILE_CHOOSER_CONFIRMATION_ACCEPT_FILENAME;
 		else
-			return GTK_FILE_CHOOSER_CONFIRMATION_SELECT_AGAIN;
+			res = GTK_FILE_CHOOSER_CONFIRMATION_SELECT_AGAIN;
 	}
 	else
 	{
 		/* fall back to the default confirmation dialog */
-		return GTK_FILE_CHOOSER_CONFIRMATION_CONFIRM;
+		res = GTK_FILE_CHOOSER_CONFIRMATION_CONFIRM;
 	}
+
+	g_free (uri);
+
+	return res;
 }
 
 static void
@@ -1463,8 +1470,7 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 					    gint                          response_id,
 					    GeditWindow                  *window)
 {
-	const GList *unsaved_documents;
-	const GList *selected_documents;
+	GList *selected_documents;
 	gboolean is_closing_all;
 
 	gedit_debug (DEBUG_COMMANDS);
@@ -1474,8 +1480,6 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 
 	gtk_widget_hide (GTK_WIDGET (dlg));
 
-	unsaved_documents = gedit_close_confirmation_dialog_get_unsaved_documents (dlg);
-
 	switch (response_id)
 	{
 		case GTK_RESPONSE_YES: /* Save and Close */
@@ -1509,6 +1513,9 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 								 window);
 				}
 			}
+
+			g_list_free (selected_documents);
+
 			break;
 
 		case GTK_RESPONSE_NO: /* Close without Saving */
@@ -1524,6 +1531,9 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 			}
 			else
 			{
+				const GList *unsaved_documents;
+
+				unsaved_documents = gedit_close_confirmation_dialog_get_unsaved_documents (dlg);
 				g_return_if_fail (unsaved_documents->next == NULL);
 
 				close_document (window,
