@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-debug.h,v 1.9 2005/12/12 17:27:55 pborelli Exp $
+ * $Id: gedit-debug.h,v 1.10.2.1 2006/04/08 14:46:31 pborelli Exp $
  */
 
 #ifndef __GEDIT_DEBUG_H__
@@ -47,14 +47,16 @@ typedef enum {
 	GEDIT_DEBUG_PRINT    = 1 << 2,
 	GEDIT_DEBUG_PREFS    = 1 << 3,
 	GEDIT_DEBUG_PLUGINS  = 1 << 4,
-	GEDIT_DEBUG_FILE     = 1 << 5,
+	GEDIT_DEBUG_TAB      = 1 << 5,
 	GEDIT_DEBUG_DOCUMENT = 1 << 6,
 	GEDIT_DEBUG_COMMANDS = 1 << 7,
 	GEDIT_DEBUG_APP      = 1 << 8,
 	GEDIT_DEBUG_SESSION  = 1 << 9,
 	GEDIT_DEBUG_UTILS    = 1 << 10,
 	GEDIT_DEBUG_METADATA = 1 << 11,
-	GEDIT_DEBUG_WINDOW   = 1 << 12,	
+	GEDIT_DEBUG_WINDOW   = 1 << 12,
+	GEDIT_DEBUG_LOADER   = 1 << 13,
+	GEDIT_DEBUG_SAVER    = 1 << 14
 } GeditDebugSection;
 
 
@@ -63,7 +65,7 @@ typedef enum {
 #define	DEBUG_PRINT	GEDIT_DEBUG_PRINT,   __FILE__, __LINE__, G_STRFUNC
 #define	DEBUG_PREFS	GEDIT_DEBUG_PREFS,   __FILE__, __LINE__, G_STRFUNC
 #define	DEBUG_PLUGINS	GEDIT_DEBUG_PLUGINS, __FILE__, __LINE__, G_STRFUNC
-#define	DEBUG_FILE	GEDIT_DEBUG_FILE,    __FILE__, __LINE__, G_STRFUNC
+#define	DEBUG_TAB	GEDIT_DEBUG_TAB,     __FILE__, __LINE__, G_STRFUNC
 #define	DEBUG_DOCUMENT	GEDIT_DEBUG_DOCUMENT,__FILE__, __LINE__, G_STRFUNC
 #define	DEBUG_COMMANDS	GEDIT_DEBUG_COMMANDS,__FILE__, __LINE__, G_STRFUNC
 #define	DEBUG_APP	GEDIT_DEBUG_APP,     __FILE__, __LINE__, G_STRFUNC
@@ -71,6 +73,8 @@ typedef enum {
 #define	DEBUG_UTILS	GEDIT_DEBUG_UTILS,   __FILE__, __LINE__, G_STRFUNC
 #define	DEBUG_METADATA	GEDIT_DEBUG_METADATA,__FILE__, __LINE__, G_STRFUNC
 #define	DEBUG_WINDOW	GEDIT_DEBUG_WINDOW,  __FILE__, __LINE__, G_STRFUNC
+#define	DEBUG_LOADER	GEDIT_DEBUG_LOADER,  __FILE__, __LINE__, G_STRFUNC
+#define	DEBUG_SAVER	GEDIT_DEBUG_SAVER,   __FILE__, __LINE__, G_STRFUNC
 
 void gedit_debug_init (void);
 
