@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-document.h,v 1.45 2006/01/19 18:16:00 paolo Exp $
+ * $Id: gedit-document.h,v 1.46 2006/02/19 18:01:09 pborelli Exp $
  */
  
 #ifndef __GEDIT_DOCUMENT_H__
@@ -154,12 +154,12 @@ gchar		*gedit_document_get_mime_type 	(GeditDocument       *doc);
 
 gboolean	 gedit_document_get_readonly 	(GeditDocument       *doc);
 
-gboolean	 gedit_document_load 		(GeditDocument       *doc, 
-						 const gchar         *uri, 
+void		 gedit_document_load 		(GeditDocument       *doc,
+						 const gchar         *uri,
 						 const GeditEncoding *encoding,
 						 gint                 line_pos,
 						 gboolean             create); 
-						 
+
 gboolean	 gedit_document_insert_file	(GeditDocument       *doc,
 						 GtkTextIter         *iter, 
 						 const gchar         *uri, 
