@@ -734,7 +734,7 @@ show_saving_message_area (GeditTab *tab)
 
 		from = short_name;
 
-		to = gnome_vfs_format_uri_for_display (tab->priv->tmp_save_uri);
+		to = gedit_utils_format_uri_for_display (tab->priv->tmp_save_uri);
 
 		str = gedit_utils_str_middle_truncate (to, 
 						       MAX (20, MAX_MSG_LENGTH - len));
@@ -1600,10 +1600,11 @@ static GdkPixbuf *
 resize_icon (GdkPixbuf *pixbuf,
 	     gint       size)
 {
-	guint width, height;
-	
+	gint width, height;
+
 	width = gdk_pixbuf_get_width (pixbuf); 
 	height = gdk_pixbuf_get_height (pixbuf);
+
 	/* if the icon is larger than the nominal size, scale down */
 	if (MAX (width, height) > size) 
 	{
