@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-view.c,v 1.66 2006/01/30 09:17:51 pborelli Exp $ 
+ * $Id: gedit-view.c,v 1.70 2006/02/24 10:31:31 pborelli Exp $ 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -64,6 +64,9 @@ typedef enum
 struct _GeditViewPrivate
 {
 	GtkTooltips *tooltips;
+
+	/* idle hack to make open-at-line work */
+	guint        scroll_idle;
 	
 	SearchMode   search_mode;
 	
@@ -316,6 +319,7 @@ scroll_to_cursor_on_init (GeditView *view)
 {
 	gedit_view_scroll_to_cursor (view);
 
+	view->priv->scroll_idle = 0;
 	return FALSE;
 }
 
@@ -380,7 +384,7 @@ gedit_view_init (GeditView *view)
 	 * possible: see bug #172277 and bug #311728.
 	 * So we need to do this in an idle handler.
 	 */
-	g_idle_add ((GSourceFunc) scroll_to_cursor_on_init, view);
+	view->priv->scroll_idle = g_idle_add ((GSourceFunc) scroll_to_cursor_on_init, view);
 	
 	view->priv->typeselect_flush_timeout = 0;	
 	view->priv->wrap_around = TRUE;		   
@@ -420,6 +424,9 @@ gedit_view_finalize (GObject *object)
 	
 	if (view->priv->tooltips != NULL)
 		g_object_unref (view->priv->tooltips);
+
+	if (view->priv->scroll_idle > 0)
+		g_source_remove (view->priv->scroll_idle);
 		
 	(* G_OBJECT_CLASS (gedit_view_parent_class)->finalize) (object);
 }
@@ -487,7 +494,8 @@ gedit_view_new (GeditDocument *doc)
 void
 gedit_view_cut_clipboard (GeditView *view)
 {
-	GtkTextBuffer *buffer = NULL;
+	GtkTextBuffer *buffer;
+	GtkClipboard *clipboard;
 
 	gedit_debug (DEBUG_VIEW);
 
@@ -496,9 +504,12 @@ gedit_view_cut_clipboard (GeditView *view)
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
 	g_return_if_fail (buffer != NULL);
 
+	clipboard = gtk_widget_get_clipboard (GTK_WIDGET (view),
+					      GDK_SELECTION_CLIPBOARD);
+
 	/* FIXME: what is default editability of a buffer? */
   	gtk_text_buffer_cut_clipboard (buffer,
-  				       gtk_clipboard_get (GDK_NONE),
+  				       clipboard,
 				       !gedit_document_get_readonly (
 				       		GEDIT_DOCUMENT (buffer)));
   	
@@ -513,7 +524,8 @@ gedit_view_cut_clipboard (GeditView *view)
 void
 gedit_view_copy_clipboard (GeditView *view)
 {
-	GtkTextBuffer *buffer = NULL;
+	GtkTextBuffer *buffer;
+	GtkClipboard *clipboard;
 
 	gedit_debug (DEBUG_VIEW);
 
@@ -522,8 +534,10 @@ gedit_view_copy_clipboard (GeditView *view)
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
 	g_return_if_fail (buffer != NULL);
 
-  	gtk_text_buffer_copy_clipboard (buffer,
-  					gtk_clipboard_get (GDK_NONE));
+	clipboard = gtk_widget_get_clipboard (GTK_WIDGET (view),
+					      GDK_SELECTION_CLIPBOARD);
+
+  	gtk_text_buffer_copy_clipboard (buffer, clipboard);
 
 	/* on copy do not scroll, we are already on screen */
 }
@@ -531,7 +545,8 @@ gedit_view_copy_clipboard (GeditView *view)
 void
 gedit_view_paste_clipboard (GeditView *view)
 {
-  	GtkTextBuffer *buffer = NULL;
+  	GtkTextBuffer *buffer;
+	GtkClipboard *clipboard;
 
 	gedit_debug (DEBUG_VIEW);
 
@@ -540,9 +555,12 @@ gedit_view_paste_clipboard (GeditView *view)
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
 	g_return_if_fail (buffer != NULL);
 
+	clipboard = gtk_widget_get_clipboard (GTK_WIDGET (view),
+					      GDK_SELECTION_CLIPBOARD);
+
 	/* FIXME: what is default editability of a buffer? */
   	gtk_text_buffer_paste_clipboard (buffer,
-					 gtk_clipboard_get (GDK_NONE),
+					 clipboard,
 					 NULL,
 					 !gedit_document_get_readonly (
 						GEDIT_DOCUMENT (buffer)));
@@ -1169,6 +1187,9 @@ search_window_key_press_event (GtkWidget   *widget,
 			       GeditView   *view)
 {
 	gboolean retval = FALSE;
+	guint modifiers;
+
+	modifiers = gtk_accelerator_get_default_mod_mask ();
 
 	/* Close window */
 	if (event->keyval == GDK_Tab)
@@ -1176,7 +1197,7 @@ search_window_key_press_event (GtkWidget   *widget,
 		hide_search_window (view, FALSE);
 		retval = TRUE;
 	}
-	
+
 	/* Close window and cancel the search */
 	if (event->keyval == GDK_Escape)
 	{
@@ -1208,7 +1229,7 @@ search_window_key_press_event (GtkWidget   *widget,
 		retval = TRUE;
 	}
 
-	if (((event->state & (GDK_CONTROL_MASK | GDK_SHIFT_MASK)) == (GDK_CONTROL_MASK | GDK_SHIFT_MASK)) && 
+	if (((event->state & modifiers) == (GDK_CONTROL_MASK | GDK_SHIFT_MASK)) && 
 	    (event->keyval == GDK_g || event->keyval == GDK_G))
 	{
 		search_again (view, TRUE);
@@ -1222,7 +1243,7 @@ search_window_key_press_event (GtkWidget   *widget,
 		retval = TRUE;
 	}
 
-	if (((event->state & (GDK_CONTROL_MASK | GDK_SHIFT_MASK)) == GDK_CONTROL_MASK) && 
+	if (((event->state & modifiers) == GDK_CONTROL_MASK) && 
 	    (event->keyval == GDK_g || event->keyval == GDK_G))
 	{
 		search_again (view, FALSE);
@@ -1761,7 +1782,6 @@ reset_searched_text (GeditView *view)
 {		
 	GeditDocument *doc;
 
-	g_print ("Reset!");		
 	doc = GEDIT_DOCUMENT (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
 	
 	gedit_document_set_search_text (doc, "", GEDIT_SEARCH_DONT_SET_FLAGS);
