@@ -39,6 +39,8 @@ class SnippetData:
 			'accelerator': ''}
 
 	def __init__(self, node, library):
+		self.priv_id = node.attrib.get('id')
+
 		self.set_library(library)
 		self.set_node(node)
 
@@ -51,6 +53,8 @@ class SnippetData:
 		else:
 			self.library = None
 
+		self.id = NamespacedId(self.language(), self.priv_id).id
+
 	def set_node(self, node):
 		if self.can_modify():
 			self.node = node
@@ -64,7 +68,6 @@ class SnippetData:
 			return
 
 		self.override = node.attrib.get('override')
-		self.id = NamespacedId(self.language(), node.attrib.get('id')).id
 
 		self.properties = {}
 		props = SnippetData.PROPS.copy()
@@ -138,8 +141,11 @@ class SnippetData:
 		else:
 			return None
 	
+	def is_override(self):
+		return self.override and SnippetsLibrary().overridden[self.override]
+
 	def _override(self):
-		# Find the user file where this fella can find refugee
+		# Find the user file
 		target = SnippetsLibrary().get_user_library(self.language())
 
 		# Create a new node there with override
@@ -177,10 +183,11 @@ class SnippetData:
 	
 	def revert(self, snippet):
 		userlib = self.library()
+		self.set_library(snippet.library())
+		
 		userlib.remove(self.node)
 		
 		self.set_node(None)
-		self.set_library(snippet.library())
 
 		# Copy the properties
 		self.properties = snippet.properties
@@ -267,7 +274,7 @@ class LanguageContainer:
 		
 		try:
 			snippets[value].remove(snippet)
-		except IndexError:
+		except:
 			True
 		
 	def append(self, snippet):
@@ -284,7 +291,7 @@ class LanguageContainer:
 	def remove(self, snippet):
 		try:
 			self.snippets.remove(snippet)
-		except IndexError:
+		except:
 			True
 			
 		self._remove_prop(snippet, 'tag')
@@ -322,9 +329,13 @@ class SnippetsSystemFile:
 		self.language = None
 		self.ok = True
 		
+	def load_error(self, message):
+		sys.stderr.write("An error occurred loading " + self.path + ":\n")
+		sys.stderr.write(message + "\nSnippets in this file will not be " \
+				"available, please correct or remove the file.\n")
+
 	def _add_snippet(self, element):
-		snippet = SnippetsLibrary().add_snippet(self, element)
-		return snippet
+		self.loading_elements.append(element)
 
 	def set_language(self, element):
 		self.language = element.attrib.get('language')
@@ -338,12 +349,15 @@ class SnippetsSystemFile:
 	def _preprocess_element(self, element):
 		if not self.loaded:
 			if not element.tag == "snippets":
+				self.load_error("Root element should be `snippets' instead " \
+						"of `%s'" % element.tag)
 				return False
 			else:
 				self._set_root(element)
 				self.loaded = True
 		elif element.tag != 'snippet' and not self.insnippet:
-			snippets_debug('Element is not of type snippet: ' + element.tag)
+			self.load_error("Element should be `snippet' instead of `%s'" \
+					% element.tag)
 			return False
 		else:
 			self.insnippet = True
@@ -405,17 +419,22 @@ class SnippetsSystemFile:
 		
 		self.loaded = False
 		self.ok = False
+		self.loading_elements = []
 		
 		for element in self.parse_xml():
 			if element[1]:
 				if not self._preprocess_element(element[0]):
-					sys.stderr.write("Error while preprocessing!\n")
+					del self.loading_elements[:]
 					return
 			else:
 				if not self._process_element(element[0]):
-					sys.stderr.write("Error while post processing!\n")
+					del self.loading_elements[:]
 					return
 
+		for element in self.loading_elements:
+			snippet = SnippetsLibrary().add_snippet(self, element)
+		
+		del self.loading_elements[:]
 		self.ok = True
 
 	# This function will get the language for a file by just inspecting the
@@ -508,12 +527,12 @@ class SnippetsUserFile(SnippetsSystemFile):
 		try:
 			self.root.remove(element)
 			self.tainted = True
-		except ValueError:
+		except:
 			return
 		
 		try:
 			first = self.root[0]
-		except IndexError:
+		except:
 			# No more elements, this library is useless now
 			SnippetsLibrary().remove_library(self)
 	
@@ -545,30 +564,18 @@ class SnippetsUserFile(SnippetsSystemFile):
 class SnippetsLibraryImpl:
 	def __init__(self):
 		self._accelerator_activated_cb = None
-		
-		# Contains all the language containers which have tag/accel mappings
-		self.containers = {}
-		
-		# Contains all the library file mappings
-		self.libraries = {}
-		
-		# Contains the suppressed snippets
-		self.overridden = {}
-	
-	def set_data(self, userdir, systemdirs):
-		self.libraries = {}
-		self.containers = {}
-		self.overridden = {}
-
+		self.loaded = False
+			
+	def set_dirs(self, userdir, systemdirs):
 		self.userdir = userdir
-
-		searched = []
-		searched = self.find_libraries(userdir, searched, \
-				self._add_user_library)
+		self.systemdirs = systemdirs
 		
-		for d in systemdirs:
-			searched = self.find_libraries(d, searched, \
-					self._add_system_library)
+		self.libraries = {}
+		self.containers = {}
+		self.overridden = {}
+		self.loaded_ids = []
+
+		self.loaded = False
 	
 	def set_accelerator_callback(self, cb):
 		self._accelerator_activated_cb = cb
@@ -587,13 +594,21 @@ class SnippetsLibraryImpl:
 			return None
 		
 		snippet = SnippetData(element, library)
-		snippet = container.append(snippet)
 		
+		if snippet.id in self.loaded_ids:
+			snippets_debug('Not added snippet ' + str(library.language) + \
+					'::' + snippet['description'] + ' (duplicate)')
+			return None
+
+		snippet = container.append(snippet)
 		snippets_debug('Added snippet ' + str(library.language) + '::' + \
 				snippet['description'])
 		
 		if snippet and snippet.override:
 			self.add_override(snippet)
+		
+		if snippet.id:
+			self.loaded_ids.append(snippet.id)
 
 		return snippet
 	
@@ -608,11 +623,12 @@ class SnippetsLibraryImpl:
 	def get_user_library(self, language):
 		target = None
 		
-		for library in self.libraries[language]:
-			if isinstance(library, SnippetsUserFile) and library.modifier:
-				target = library
-			elif not isinstance(library, SnippetsUserFile):
-				break
+		if language in self.libraries:
+			for library in self.libraries[language]:
+				if isinstance(library, SnippetsUserFile) and library.modifier:
+					target = library
+				elif not isinstance(library, SnippetsUserFile):
+					break
 		
 		if not target:
 			# Create a new user file then
@@ -641,14 +657,23 @@ class SnippetsLibraryImpl:
 		revertto = self.overridden[snippet.override]
 		del self.overridden[snippet.override]
 		
-		snippet.revert(revertto)
+		if revertto:
+			snippet.revert(revertto)
+		
+			if revertto.id:
+				self.loaded_ids.append(revertto.id)
 	
 	def remove_snippet(self, snippet):
-		if not snippet.can_modify() or snippet.override:
+		if not snippet.can_modify() or snippet.is_override():
 			return
 		
+		# Remove from the library
 		userlib = snippet.library()
 		userlib.remove(snippet.node)
+		
+		# Remove from the container
+		container = self.containers[userlib.language]
+		container.remove(snippet)
 	
 	def overrided(self, library, element):
 		id = NamespacedId(library.language, element.attrib.get('id')).id
@@ -740,11 +765,16 @@ class SnippetsLibraryImpl:
 		
 		return language
 	
-	def remove_overrides(self, language):
+	def remove_container(self, language):
 		for snippet in self.containers[language].snippets:
+			if snippet.id in self.loaded_ids:
+				self.loaded_ids.remove(snippet.id)
+
 			if snippet.override in self.overridden:
 				del self.overridden[snippet.override]
-	
+
+		del self.containers[language]
+		
 	def get_accel_group(self, language):
 		language = self.normalize_language(language)
 		
@@ -764,12 +794,7 @@ class SnippetsLibraryImpl:
 	def ref(self, language):
 		language = self.normalize_language(language)
 
-		if not language in self.libraries:
-			return
-			
 		snippets_debug('Ref:', language)
-			
-		self.ensure(language)
 		self.container(language).ref()
 	
 	def unref(self, language):
@@ -778,29 +803,46 @@ class SnippetsLibraryImpl:
 		snippets_debug('Unref:', language)
 		
 		if language in self.containers:
-			if not self.containers[language].unref():
+			if not self.containers[language].unref() and \
+					language in self.libraries:
+
 				for library in self.libraries[language]:
 					library.unload()
 				
-				self.remove_overrides(language)
-				
-				del self.containers[language]
+				self.remove_container(language)
 
 	def ensure(self, language):
 		language = self.normalize_language(language)
-		
-		if language in self.libraries:
+
+		# Ensure language as well as the global snippets (None)
+		for lang in (None, language):
+			if lang in self.libraries:
 			# Ensure the container exists
-			self.container(language)
-			
-			for library in self.libraries[language]:
-				library.ensure()
-	
+				self.container(lang)
+
+				for library in self.libraries[lang]:
+					library.ensure()
+
+	def ensure_files(self):
+		if self.loaded:
+			return
+
+		searched = []
+		searched = self.find_libraries(self.userdir, searched, \
+				self._add_user_library)
+		
+		for d in self.systemdirs:
+			searched = self.find_libraries(d, searched, \
+					self._add_system_library)
+
+		self.loaded = True
+
 	# Snippet getters
 	# ===============
 	
 	# Get snippets for a given language
 	def get_snippets(self, language=None):
+		self.ensure_files()
 		language = self.normalize_language(language)
 		
 		if not language in self.libraries:
@@ -809,12 +851,13 @@ class SnippetsLibraryImpl:
 		snippets = []
 		self.ensure(language)
 		
-		return self.containers[language].snippets
+		return list(self.containers[language].snippets)
 
 	# Get snippets for a given accelerator
 	def from_accelerator(self, accelerator, language=None):
-		result = []
+		self.ensure_files()
 		
+		result = []		
 		language = self.normalize_language(language)
 			
 		if not language in self.containers:
@@ -830,8 +873,9 @@ class SnippetsLibraryImpl:
 
 	# Get snippets for a given tag
 	def from_tag(self, tag, language=None):
-		result = []
+		self.ensure_files()
 		
+		result = []
 		language = self.normalize_language(language)
 			
 		if not language in self.containers:
